@@ -9,19 +9,13 @@ from django.contrib.staticfiles.testing import LiveServerTestCase
 
 
 @pytest.mark.client
+@pytest.mark.usefixtures("import_translations_fixture")
 class TestTranslateClientModel(LiveServerTestCase):
     """Tests for ``TranslateClient`` utils methods."""
 
     # TODO: Implement lifecycle of functional tests using pytest and not django way.
-    #  Mixing those usually comes at the cost.
-
-    def setUp(self):
-        """Set's up test data for a test."""
-        from django.core.management import call_command
-
-        call_command(
-            "import_translations", translations_dir="translate/service/tests/fixtures"
-        )
+    #  Mixing those usually comes at the cost - we have to physically run the server and seperate the tests runners without parallelization. This is not ideal.
+    # Partial splitting here has been done to clean it up a bit. Flaky tests should be fixed with it, however parallelization is still not possible due to the LiveServerTestCase (which should be set up as individual fixture).
 
     def test_filter(self):
         """Tests ``filter`` method without additional filters."""
@@ -151,34 +145,64 @@ class TestTranslateClientModel(LiveServerTestCase):
 
         assert not no_response, "Should have returned no values."
 
-    def test_response_pagination(self):
+    def test_filter_pagination(self):
         """Test JSON response for different pages."""
         from melon_translate_client import Client
 
         port = self.live_server_url.split(":")[2]
-        c = Client(config("TRANSLATE_ADDRESS", default="http://localhost"), port)
+        client = Client(config("TRANSLATE_ADDRESS", default="http://localhost"), port)
         language = "de"
 
-        first_page_response = c.filter(language, page_size=4, page=1, no_cache=True)
+        first_page_response = client.filter(
+            language, page_size=4, page=1, no_cache=True
+        )
         assert (
             first_page_response.status_code == requests.status_codes.codes.ok
         ), "Should have returned HTTP status code 200 OK."
-        assert first_page_response.json(), "Should have returned some values."
+        assert {"count", "links", "pages", "results"} == set(
+            first_page_response.json().keys()
+        )
         assert (
-            len(first_page_response.json()) == 4
+            len(first_page_response.json().get("results")) == 4
         ), "Should return same number of records as stated in ``page_size`` parameter."
 
         # Request results from second page.
-        second_page_response = c.filter(language, page_size=4, page=2, no_cache=True)
+        second_page_response = client.filter(
+            language, page_size=4, page=2, no_cache=True
+        )
         assert (
             second_page_response.status_code == requests.status_codes.codes.ok
         ), "Should have returned HTTP status code 200 OK."
         assert (
             first_page_response.json() is not second_page_response.json()
         ), "Should have returned different values from the first page."
+        assert {"count", "links", "pages", "results"} == set(
+            second_page_response.json().keys()
+        )
         assert (
-            len(first_page_response.json()) == 4
+            len(second_page_response.json()) == 4
         ), "Should return same number of records as stated in ``page_size`` parameter."
+        assert first_page_response.json().get(
+            "count"
+        ) == second_page_response.json().get("count")
+
+    def test__get_all_pages(self):
+        """Test JSON response for different pages."""
+        from melon_translate_client import Client
+
+        port = self.live_server_url.split(":")[2]
+        client = Client(config("TRANSLATE_ADDRESS", default="http://localhost"), port)
+        language = "de"
+
+        responses = client._get_all_pages(
+            language, page_size=4, page=1, chain_together=False
+        )
+        assert len(responses) == 2, "Should return 2 pages of results."
+
+        first_page_response, second_page_response, *_ = responses
+        assert first_page_response["count"] == second_page_response["count"]
+        assert len(first_page_response["results"]) == 4
+        assert len(second_page_response["results"]) == 4
 
     def test_redis_caching_for_filter_method(self):
         """Tests redis caching for filter method with additional filters."""
@@ -188,14 +212,14 @@ class TestTranslateClientModel(LiveServerTestCase):
         cache.flushall()
 
         port = self.live_server_url.split(":")[2]
-        c = Client(config("TRANSLATE_ADDRESS", default="http://localhost"), port)
+        client = Client(config("TRANSLATE_ADDRESS", default="http://localhost"), port)
 
         language = "de"
-        _ = c.filter(
+        _ = client.filter(
             language,
             views=["translation_center"],
         )
-        _ = c.filter(
+        _ = client.filter(
             language,
             occurrences=[
                 "new_mdt/apps/mdt_apartments/api/docs.py",
@@ -204,9 +228,7 @@ class TestTranslateClientModel(LiveServerTestCase):
 
         maps_no_expire = [
             f"{language}_id_name",
-            f"{language}_occurrences",
             f"{language}_snake_name",
-            f"{language}_views",
         ]
         for key in maps_no_expire:
             assert cache.hgetall(key), "Should have returned some values."
@@ -214,4 +236,15 @@ class TestTranslateClientModel(LiveServerTestCase):
                 cache.ttl(key) == -1
             ), "TTL for reverse indexes and values should always be None. We only expire indexes."
 
-        assert c.snake_key(language, "admin_dossier_downloading")
+        maps_with_ttl = [
+            f"{language}_views",
+            f"{language}_occurrences",
+        ]
+
+        for key in maps_with_ttl:
+            assert cache.hgetall(key), "Should have returned some values."
+            assert (
+                cache.ttl(key) == 2700
+            ), "TTL for views and occurrences should be 45 minutes or 2700 seconds"
+
+        assert client.snake_key(language, "admin_dossier_downloading")
